==> php81-nextcloud-26.0.5.tgz: share/nextcloud/apps/workflowengine/l10n/gl.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "O operador indicado é incorrecto",
    "The given regular expression is invalid" : "A expresión regular indicada é incorrecta",
    "The given file size is invalid" : "O tamaño do ficheiro indicado é incorrecto",
    "The given tag id is invalid" : "A etiqueta indicada é incorrecta",
    "The given IP range is invalid" : "O intervalo de IP indicado é incorrecto",
    "The given IP range is not valid for IPv4" : "O intervalo de IP indicado é incorrecto para IPv4",
    "The given IP range is not valid for IPv6" : "O intervalo de IP indicado é incorrecto para IPv6",
    "The given time span is invalid" : "O intervalo temporal indicado é incorrecto",
    "The given start time is invalid" : "A hora de inicio indicada é incorrecta",
    "The given end time is invalid" : "A hora final indicada é incorrecta",
    "The given group does not exist" : "O grupo indicado non existe",
    "File" : "Ficheiro",
    "File created" : "Ficheiro creado",
    "File updated" : "Ficheiro actualizado",
    "File renamed" : "Ficheiro renomeado",
    "File deleted" : "Ficheiro eliminado",
    "File accessed" : "Ficheiro accedido",
    "File copied" : "Ficheiro copiado",
    "Tag assigned" : "Etiqueta asignada",
    "Someone" : "Someone",
    "%s created %s" : "%s creado %s",
    "%s modified %s" : "%s modificado %s",
    "%s deleted %s" : "%s eliminado %s",
    "%s accessed %s" : "%s accedido %s",
    "%s renamed %s" : "%s renomeado %s",
    "%s copied %s" : "%s copiado %s",
    "%s assigned %s to %s" : "%s asignado %s a %s",
    "Operation #%s does not exist" : "Non existe a operación nº %s ",
    "Entity %s does not exist" : "Non existe a entidade %s",
    "Entity %s is invalid" : "A entidade %s é incorrecta",
    "No events are chosen." : "Non foi escollido ningún evento.",
    "Entity %s has no event %s" : "A entidade %s non ten ningún evento %s",
    "Operation %s does not exist" : "Non existe a operación %s",
    "Operation %s is invalid" : "A operación %s é incorrecta",
    "At least one check needs to be provided" : "É necesario fornecer polo menos unha comprobación",
    "The provided operation data is too long" : "Os datos de operación fornecidos son demasiado longos",
    "Invalid check provided" : "Forneceuse unha confirmación incorrecta",
    "Check %s does not exist" : "Non existe a proba %s",
    "Check %s is invalid" : "A proba %s é incorrecta",
    "Check %s is not allowed with this entity" : "A proba %s non está permitida con esta entidade",
    "The provided check value is too long" : "O valor de comprobación fornecido é demasiado longo",
    "Check #%s does not exist" : "Non existe a proba nº %s ",
    "Check %s is invalid or does not exist" : "A proba %s é incorrecta ou non existe",
    "Flow" : "Fluxo",
    "Nextcloud workflow engine" : "Motor de fluxo de traballo de Nextcloud",
    "Select a filter" : "Seleccione un filtro",
    "Select a comparator" : "Seleccione un comparador",
    "Remove filter" : "Retirar o filtro",
    "Select a file type" : "Seleccione un tipo de ficheiro",
    "e.g. httpd/unix-directory" : "p. ex.: httpd/unix-directory",
    "Folder" : "Cartafol",
    "Images" : "Imaxes",
    "Office documents" : "Documentos de oficina",
    "PDF documents" : "Documentos PDF",
    "Custom MIME type" : "Tipo MIME personalizado",
    "Custom mimetype" : "Tipo MIME personalizado",
    "Please enter a valid time span" : "Introduza un intervalo de tempo válido",
    "Select a request URL" : "Seleccione un URL de solicitude",
    "Files WebDAV" : "Ficheiros WebDAV",
    "Custom URL" : "URL personalizado",
    "Select a user agent" : "Seleccionar un axente de usuario",
    "Android client" : "Cliente Android",
    "iOS client" : "Cliente iOS",
    "Desktop client" : "Cliente de escritorio",
    "Thunderbird & Outlook addons" : "Complementos do Thunderbird e do Outlook",
    "Custom user agent" : "Axente de usuario personalizado",
    "Select a trigger" : "Seleccione un disparador",
    "At least one event must be selected" : "Ten que seleccionar polo menos un evento",
    "Add new flow" : "Engadir un novo fluxo",
    "When" : "Cando",
    "and" : "e",
    "Add a new filter" : "Engadir un novo filtro",
    "Cancel" : "Cancelar",
    "Delete" : "Eliminar",
    "The configuration is invalid" : "A configuración é incorrecta",
    "Active" : "Activo",
    "Save" : "Gardar",
    "Available flows" : "Fluxos dispoñíbeis",
    "For details on how to write your own flow, check out the development documentation." : "Para obter máis detalles sobre como escribir o seu propio fluxo, consulte a documentación de desenvolvemento.",
    "More flows" : "Máis fluxos",
    "Browse the App Store" : "Navega pola Tenda de Aplicacións",
    "Show less" : "Amosar menos",
    "Show more" : "Amosar máis",
    "Configured flows" : "Fluxos configurados",
    "Your flows" : "Os seus fluxos",
    "matches" : "coincidencias",
    "does not match" : "non coinciden",
    "is" : "é",
    "is not" : "non é",
    "File name" : "Nome de ficheiro",
    "File MIME type" : "Tipo MIME do ficheiro",
    "File size (upload)" : "Tamaño do ficheiro (envío)",
    "less" : "menor",
    "less or equals" : "menor ou igual",
    "greater or equals" : "maior ou igual",
    "greater" : "maior",
    "Request remote address" : "Enderezo da solicitude remota",
    "matches IPv4" : "coincidencias IPv4",
    "does not match IPv4" : "sen coincidencias IPv4",
    "matches IPv6" : "coincidencias IPv6",
    "does not match IPv6" : "sen coincidencias IPv6",
    "File system tag" : "Etiqueta do sistema de ficheiros",
    "is tagged with" : "está etiquetado con",
    "is not tagged with" : "non está etiquetado con",
    "Request URL" : "URL da solicitude",
    "Request time" : "Momento da solicitude",
    "between" : "entre",
    "not between" : "non entre",
    "Request user agent" : "Cliente usado para a solicitude",
    "User group membership" : "Pertenza a un grupo de usuarios",
    "is member of" : "é membro de",
    "is not member of" : "non é membro de",
    "Predefined URLs" : "URL predefinidos",
    "Others" : "Outros"
},
"nplurals=2; plural=(n != 1);");

==> php81-nextcloud-32.0.1.tgz: share/nextcloud/apps/workflowengine/l10n/gl.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "O operador indicado é incorrecto",
    "The given regular expression is invalid" : "A expresión regular indicada é incorrecta",
    "The given file size is invalid" : "O tamaño do ficheiro indicado é incorrecto",
    "The given tag id is invalid" : "A etiqueta indicada é incorrecta",
    "The given IP range is invalid" : "O intervalo de IP indicado é incorrecto",
    "The given IP range is not valid for IPv4" : "O intervalo de IP indicado é incorrecto para IPv4",
    "The given IP range is not valid for IPv6" : "O intervalo de IP indicado é incorrecto para IPv6",
    "The given time span is invalid" : "O intervalo temporal indicado é incorrecto",
    "The given start time is invalid" : "A hora de inicio indicada é incorrecta",
    "The given end time is invalid" : "A hora final indicada é incorrecta",
    "The given group does not exist" : "O grupo indicado non existe",
    "File" : "Ficheiro",
    "File created" : "Ficheiro creado",
    "File updated" : "Ficheiro actualizado",
    "File renamed" : "Ficheiro renomeado",
    "File deleted" : "Ficheiro eliminado",
    "File accessed" : "Ficheiro accedido",
    "File copied" : "Ficheiro copiado",
    "Tag assigned" : "Etiqueta asignada",
    "Someone" : "Someone",
    "%s created %s" : "%s creado %s",
    "%s modified %s" : "%s modificado %s",
    "%s deleted %s" : "%s eliminado %s",
    "%s accessed %s" : "%s accedido %s",
    "%s renamed %s" : "%s renomeado %s",
    "%s copied %s" : "%s copiado %s",
    "%s assigned %s to %s" : "%s asignado %s a %s",
    "Operation #%s does not exist" : "Non existe a operación nº %s ",
    "Entity %s does not exist" : "Non existe a entidade %s",
    "Entity %s is invalid" : "A entidade %s é incorrecta",
    "No events are chosen." : "Non foi escollido ningún evento.",
    "Entity %s has no event %s" : "A entidade %s non ten ningún evento %s",
    "Operation %s does not exist" : "Non existe a operación %s",
    "Operation %s is invalid" : "A operación %s é incorrecta",
    "At least one check needs to be provided" : "É necesario fornecer polo menos unha comprobación",
    "The provided operation data is too long" : "Os datos de operación fornecidos son demasiado longos",
    "Invalid check provided" : "Forneceuse unha confirmación incorrecta",
    "Check %s does not exist" : "Non existe a proba %s",
    "Check %s is invalid" : "A proba %s é incorrecta",
    "Check %s is not allowed with this entity" : "A proba %s non está permitida con esta entidade",
    "The provided check value is too long" : "O valor de comprobación fornecido é demasiado longo",
    "Check #%s does not exist" : "Non existe a proba nº %s ",
    "Check %s is invalid or does not exist" : "A proba %s é incorrecta ou non existe",
    "Flow" : "Fluxo",
    "Nextcloud workflow engine" : "Motor de fluxo de traballo de Nextcloud",
    "Select a filter" : "Seleccione un filtro",
    "Select a comparator" : "Seleccione un comparador",
    "Remove filter" : "Retirar o filtro",
    "Audio" : "Son",
    "Folder" : "Cartafol",
    "Images" : "Imaxes",
    "Office documents" : "Documentos de oficina",
    "PDF documents" : "Documentos PDF",
    "Video" : "Vídeo",
    "Custom MIME type" : "Tipo MIME personalizado",
    "Custom mimetype" : "Tipo MIME personalizado",
    "Select a file type" : "Seleccione un tipo de ficheiro",
    "e.g. httpd/unix-directory" : "p. ex.: httpd/unix-directory",
    "Please enter a valid time span" : "Introduza un intervalo de tempo válido",
    "Files WebDAV" : "Ficheiros WebDAV",
    "Custom URL" : "URL personalizado",
    "Select a request URL" : "Seleccione un URL de solicitude",
    "Android client" : "Cliente Android",
    "iOS client" : "Cliente iOS",
    "Desktop client" : "Cliente de escritorio",
    "Thunderbird & Outlook addons" : "Complementos do Thunderbird e do Outlook",
    "Custom user agent" : "Axente de usuario personalizado",
    "Select a user agent" : "Seleccionar un axente de usuario",
    "Select groups" : "Seleccionar grupos",
    "Groups" : "Grupos",
    "Type to search for group …" : "Escriba para buscar por grupo…",
    "Select a trigger" : "Seleccione un activador",
    "At least one event must be selected" : "Ten que seleccionar polo menos un evento",
    "Add new flow" : "Engadir un novo fluxo",
    "The configuration is invalid" : "A configuración é incorrecta",
    "Active" : "Activo",
    "Save" : "Gardar",
    "When" : "Cando",
    "and" : "e",
    "Add a new filter" : "Engadir un novo filtro",
    "Cancel" : "Cancelar",
    "Delete" : "Eliminar",
    "Available flows" : "Fluxos dispoñíbeis",
    "For details on how to write your own flow, check out the development documentation." : "Para obter máis detalles sobre como escribir o seu propio fluxo, consulte a documentación de desenvolvemento.",
    "No flows installed" : "Non hai ningún fluxo instalado",
    "Ask your administrator to install new flows." : "Pídalle á administración do sitio que instale novos fluxos.",
    "More flows" : "Máis fluxos",
    "Browse the App Store" : "Navega pola Tenda de Aplicacións",
    "Show less" : "Amosar menos",
    "Show more" : "Amosar máis",
    "Configured flows" : "Fluxos configurados",
    "Your flows" : "Os seus fluxos",
    "No flows configured" : "Non hai ningún fluxo configurado",
    "matches" : "coincidencias",
    "does not match" : "non coinciden",
    "is" : "é",
    "is not" : "non é",
    "File name" : "Nome de ficheiro",
    "File MIME type" : "Tipo MIME do ficheiro",
    "File size (upload)" : "Tamaño do ficheiro (envío)",
    "less" : "menor",
    "less or equals" : "menor ou igual",
    "greater or equals" : "maior ou igual",
    "greater" : "maior",
    "Request remote address" : "Enderezo da solicitude remota",
    "matches IPv4" : "coincidencias IPv4",
    "does not match IPv4" : "sen coincidencias IPv4",
    "matches IPv6" : "coincidencias IPv6",
    "does not match IPv6" : "sen coincidencias IPv6",
    "File system tag" : "Etiqueta do sistema de ficheiros",
    "is tagged with" : "está etiquetado con",
    "is not tagged with" : "non está etiquetado con",
    "Request URL" : "URL da solicitude",
    "Request time" : "Momento da solicitude",
    "between" : "entre",
    "not between" : "non entre",
    "Request user agent" : "Cliente usado para a solicitude",
    "Group membership" : "Pertenza ao grupo",
    "is member of" : "é membro de",
    "is not member of" : "non é membro de",
    "Type to search for group …" : "Escriba para buscar por grupo…"
},
"nplurals=2; plural=(n != 1);");
